\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{myxetexclass}[2024/09/14 XeLaTeX Class with Times New Roman]

\RequirePackage{iftex}

\ifXeTeX
  % Do nothing, XeLaTeX is being used
\else
  \errmessage{This document class requires XeLaTeX to compile. Please use the XeLaTeX engine.}
\fi

\LoadClass{article}
\setlength{\paperwidth}{210mm}  % A4 width
\setlength{\paperheight}{297mm} % A4 height


\usepackage[backend=bibtex,style=ieee,citestyle=numeric-comp]{biblatex}
\DeclareFieldFormat{labelnumber}{\normalfont#1}
%\DeclareFieldFormat{cite}{\normalfont[#1]}


\RequirePackage{geometry}
\geometry{
  left=1.25in,
  right=1.25in,
  top=1in,
  bottom=1in
}



% Font settings
\RequirePackage{fontspec}
%\usepackage{unicode-math} % Required for \setmathfont command
\setmainfont{Times New Roman}[LetterSpace=0.2pt]

% Optionally set sans-serif and monospaced fonts
\setsansfont{Arial}
\setmonofont{Courier New}

%------paper-size-begin----------%

% Adjust margins directly

\setlength\textheight{8.9in}
\setlength{\headsep}{45.5pt} 
\setlength{\parindent}{21.55pt}
% \setlength{\footskip}{1pt}       % Space between footer and text
% \setlength{\oddsidemargin}{1in}   % Left margin for odd pages
% \setlength{\evensidemargin}{1in}  % Left margin for even pages (for two-sided docs)
% \setlength{\topmargin}{-39.3pt}       % Top margin
% \setlength{\textwidth}{416pt}     % Text width
% \setlength{\textheight}{9in}      % Text height
% \setlength{\headheight}{30pt}      % Header height (if no header)
% \setlength{\headsep}{0.5in}         % Space between header and text
% \setlength{\footskip}{15pt}       % Space between footer and text
%------paper-size-begin----------%



\usepackage{setspace}
\usepackage{caption}  % For customizing captions
\usepackage{calc}
\usepackage{ragged2e}
\usepackage{array}
\usepackage{enumitem} % Allows customization of lists
\usepackage{forloop}

%\usepackage{tablefootnote}

% Command to set table row spacing
\newcommand{\setTableRowSpacing}[1]{%
    \renewcommand{\arraystretch}{#1} % Set row spacing
}

\renewenvironment{abstract}{
    \renewcommand{\parindent}{0pt} % Disable indentation in abstract
    {\vspace{2.5pt}}
    {\fontsize{10}{12}\selectfont\noindent\textbf{Abstract}}\\
    \vskip -5.8pt
    \small
    {\fontsize{9}{11}\selectfont % Paragraph size 9pt    
    \ignorespaces
    %\vskip -11pt
    }\noindent\ignorespaces
}





% Set caption alignment to the left
\captionsetup{
    justification=centering,
    singlelinecheck=false,
    labelfont=bf,
    labelsep = period,
    parskip=10pt,
}
\setlength{\abovecaptionskip}{2pt}


% Pass options to the base class
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions\relax




% Use fontspec to manage fonts in XeLaTeX
\RequirePackage{changepage}
\RequirePackage{fontspec}
\RequirePackage[RGB]{xcolor}    % For setting custom colors
%\usepackage[a-1b]{pdfx}
\usepackage{hyperref}
\usepackage{url}
\urlstyle{same}
% \definecolor{hyperlinkcolor}{cmyk}{1.000, 0.834, 0.000, 0.102}
% \definecolor{openaccesslinkcolor}{cmyk}{0.63, 0.19, 0.0,0.43}
% \definecolor{titlecolor}{cmyk}{0.37,0.22,0.0,0.69}

\definecolor{hyperlinkcolor}{cmyk}{1.000, 0.834, 0.000, 0.102}
\definecolor{openaccesslinkcolor}{RGB}{53, 117, 145}
\definecolor{titlecolor}{RGB}{50,62,79}


% After pdfx loads hyperref, you can set additional options
\hypersetup{
    colorlinks=true, 
    urlcolor=openaccesslinkcolor, 
    linkcolor=black, 
    citecolor=black
}

\newcommand{\copyrightyear}[1]{\def\@copyrightyear{#1}}
\def\@copyrightyear{}

\newcommand{\proceedingvol}[1]{\def\@proceedingvol{#1}}
\def\@proceedingvol{}

\newcommand{\proceedingyear}[1]{\def\@proceedingyear{#1}}
\def\@proceedingyear{}

\newcommand{\artid}[1]{\def\@artid{#1}}
\def\@artid{}

\newcommand{\proceedingsubj}[1]{\def\@proceedingsubj{#1}}
\def\@proceedingsubj{}

\newcommand{\DOI}[1]{\def\@DOI{#1}}
\def\@DOI{}




\newcommand{\copyrightline}[1]{\def\@copyrightline{\textcopyright\space\@copyrightyear\space\copylinefnt#1}}
\def\@copyrightline{}

\def\copylinefnt{\fontsize{8.5}{12}\selectfont}%




%-------------first page logo - start ----------------%

\RequirePackage{fancyhdr} % For custom page headers/footers

% Define the title page style
\def\logoname{}
\def\journalname{}

\def\slugheadfnt{\fontsize{10}{11}\selectfont}%
\def\pgnumfnt{\fontsize{9}{0}\selectfont}%
\def\prctitle{\fontsize{12}{14}\selectfont}%
\def\headfnt{\fontsize{9}{0}\selectfont\bfseries\itshape}%
\def\titlefnt{\fontsize{16}{18}\selectfont\bfseries\color{titlecolor}}%
\def\normalsize{\fontsize{10}{12}\selectfont}%
\def\tablefooterfont{\fontsize{8}{10}\selectfont}%
\newcommand{\articleType}

\def\logowidth{109pt}
\def\logoheight{31pt}
%\def\pgnumpos{-30pt}
\newlength{\pgnumpos}
\setlength{\pgnumpos}{-3\baselineskip}


\newcommand{\receiveddate}{}
\newcommand{\reviseddate}{}
\newcommand{\accepteddate}{}

\newcommand{\setdates}[3]{%
    \renewcommand{\receiveddate}{Received: #1}%
    \renewcommand{\reviseddate}{Revised: #2}%
    \renewcommand{\accepteddate}{Accepted: #3}%
}
\renewcommand{\@cite}[2]{\textnormal{#1}} % Format citations as [1]
% \renewcommand{\thefigure}{\arabic{figure}.} % Figures as [1]
% \renewcommand{\thetable}{\arabic{table}.}   % Tables as [1]
% \renewcommand{\theequation}{[\arabic{equation}]} % Equations as [1]

\newlength{\secwidth}

\newcommand{\settextwidth}[1]{%
  \settowidth{\secwidth}{#1}
}

% \renewcommand{\@seccntformat}[1]{%
%     \settextwidth{\csname the#1\endcsname}{%
%     \noindent\ignorespaces\csname the#1\endcsname\hspace{\dimexpr\parindent-\secwidth-1pt}}
%     } % Use \parindent to match paragraph indentation


\renewcommand{\@seccntformat}[1]{%
    \noindent\ignorespaces\csname the#1\endcsname\hspace{14pt}
    } %

\newlength{\firstpagerule}
   \def\ps@headings{%
    \let\@oddfoot\@empty % Clear odd page footers
    \let\@evenfoot\@empty % Clear even page footers
   \gdef\@oddhead{\checkoddpage\ifoddpage\hbox to \textwidth{\headfnt\@proceedingsubj\hfill\includegraphics[width=\jrnlogowidth,height=\jrnlogoheight]{\logoname.eps}}\else\hbox to \textwidth{\headfnt\includegraphics[width=\jrnlogowidth,height=\jrnlogoheight]{\logoname.eps}\hfill\@proceedingsubj}\fi}%

   \gdef\@evenhead{\hbox to \textwidth{\headfnt\includegraphics[width=\jrnlogowidth,height=\jrnlogoheight]{\logoname.eps}\hfill\@proceedingsubj}}%
   \def\@oddfoot{\raisebox{\pgnumpos}{\hbox to\textwidth{\hfill\pgnumfnt\thepage}}}
  \def\@evenfoot{\raisebox{\pgnumpos}{\hbox to\textwidth{\hfil\pgnumfnt\thepage}}}
    %\def\@oddfoot{\hbox to\textwidth{\hfill\pgnumfnt\thepage}}
    %\def\@evenfoot{\hbox to\textwidth{\hfil\pgnumfnt\thepage}}

    % \setlength{\topmargin}{-43pt}
    % \setlength{\headheight}{0.5in}
    % \setlength{\headsep}{0.3in}

}

% title page style
\def\ps@titlepagestyle{% Custom page style definition
  \normalfont % Use normal font (same as the document)
  \vskip 0pt
  \vspace{0pt}
   \def\@oddhead{\vbox{\vbox{\begin{tabular}{@{}p{\dimexpr\textwidth\relax}@{}r@{}}
         \vbox{{\bf\journalname}\newline{\bf Volume \@proceedingvol}\ (\@proceedingyear) \@artid\newline
          {\itshape\@proceedingsubj}} & \makebox[0pt][r]{\raisebox{-1pt}{\includegraphics[width=\jrnlogowidth,height=\jrnlogoheight]{\logoname.eps}}}
         \end{tabular}} }}
   \def\@evenhead{\vbox{\vbox{\begin{tabular}{@{}p{\dimexpr\textwidth\relax}@{}r@{}}
         \vbox{{\bf\journalname}\newline {\bf Volume \@proceedingvol}\ (\@proceedingyear) \@artid\newline
         {\itshape\@proceedingsubj}} & \makebox[0pt][r]{\raisebox{-1pt}{\includegraphics[width=\jrnlogowidth,height=\jrnlogoheight]{\logoname.eps}}}
         \end{tabular}} }}
   \def\@oddfoot{\hbox to \textwidth{ 
      \noindent
      \begin{minipage}[t]{\textwidth-15pt}{\noindent\rule[0pt]{168pt}{0.4pt}\newline\copylinefnt\noindent\@DOI\newline\@copyrightline}\end{minipage}\hfill\begin{minipage}[t]{10pt}\raisebox{\pgnumpos}{\hbox to\textwidth{\hfill\pgnumfnt\thepage}}\end{minipage}}}
   \def\@evenfoot{\hbox to \textwidth{
      \noindent
      \begin{minipage}[t]{\textwidth-15pt}{\noindent\rule[0pt]{168pt}{0.4pt}\newline\copylinefnt\noindent\@DOI\newline\@copyrightline}\end{minipage}\hfill\begin{minipage}[t]{10pt}\raisebox{\pgnumpos}{\hbox to\textwidth{\hfill\pgnumfnt\thepage}}\end{minipage}}}
    
    \noindent\hspace{18pt}\rule[0pt]{\textwidth}{0.4pt} % Properly aligned hrule
}


% Redefine \title command to accept one or two arguments
\newcommand{\subtitle}{}

\renewcommand{\title}[2][\@empty]{%
    \gdef\@title{#2}%
    \gdef\subtitle{#1}%
}




% Redefine \maketitle to include journal info, volume, and apply custom title page style
\renewcommand{\maketitle}{%

    \pagestyle{headings}
    
    \thispagestyle{titlepagestyle}% Apply the custom title page style


    % \setlength{\footskip}{10pt}   
    {\raggedright{  % Align the title to the left
    \vspace*{3.8pt}
    \MakeUppercase{\large{Proceedings Article} }\\ } % Explicitly mention article type
    {
    \hyphenpenalty=10000 % Prevent word splitting in the title
    \exhyphenpenalty=10000
    
    \vspace*{4.5pt}

    
    \ifx\subtitle\@empty % Check if there is a subtitle
          \titlefnt{\@title\ignorespaces}
      \else
          \titlefnt{\@title: \subtitle}
      \fi
    
    }
    \vskip 0em
    \vspace*{11.5pt}
    {\large \@author \par}
    \vspace*{5.9pt}
    {\setlength{\parskip}{-0.01em} % Reduce the space between affiliations
  
    \@affiliations \par}
     % If corresponding author info exists, print it

    \vspace{5.9pt}
    {\setstretch{0.995} % Reduce the overall line spacing
    {\normalsize\textsuperscript{\@correspondingauthornum}Corresponding author. Email: \href{mailto:\@corresemail}{\textcolor{blue}{\underline{\@corresemail}}} \par}
    \ifx\@otheremails\@empty
    \else
      {\normalsize\@otheremails \par}
    \fi
    \vspace{7pt}
    \textit{{\receiveddate}, {\reviseddate}, {\accepteddate} }}}
    \vskip 1em
}




\newcommand{\affil}[3]{%
  \def\temp{#3}%
    \ifx\temp\@empty
        {\g@addto@macro\@affiliations{\textit{\textsuperscript{#1}#2}\par}}
    \else
        {\g@addto@macro\@affiliations{\textit{\textsuperscript{#1}#2; \href{mailto:#3}{\textcolor{blue}{\underline{#3}}}}\par}}
    \fi
}

  

\gdef\@affiliations{}

\newcommand{\correspondingauthor}[2]{%
  \gdef\@correspondingauthornum{#1}
  \gdef\@corresemail{#2}
}

\newcommand{\otheremail}[2]{%
  \g@addto@macro\@otheremails{\vskip 0em{\textsuperscript{#1}Email: \href{mailto:#2}{\textcolor{blue}{\underline{#2}}}}}
}


\gdef\@correspondingauthor{}
\gdef\@otheremails{}




%-------------first page logo - end ------------------%



\newcommand{\authorname}[2]{%
    {\fontsize{10.08}{12}\selectfont #1}% Set author name font size to 10.08 pt
    \textsuperscript{\fontsize{6.48}{7.5}\selectfont #2}% Set superscript font size to 6.48 pt
}

% Command to format multiple authors
\newcommand{\myauthors}[1]{
    \def\temp{#1}
    \ifx\temp\empty
        \def\authors{}
    \else
        \def\authors{#1}
    \fi
    {\fontsize{10.08}{12}\selectfont{\authors}}
}

% Command to handle individual author with superscript


\AtBeginDocument{%
    \sloppy % Add this to make LaTeX more lenient with line breaks
}

\newcommand{\keywordsname}{Keywords}

% \newenvironment{keywords}{%
%   {\vspace{10.5pt}\noindent
%   \fontsize{9}{11}\selectfont\textbf{\keywordsname:\ignorespaces\hspace{-4pt}}
% }}{\fontsize{9}{11}\selectfont\par}

\newenvironment{keywords}{
    \renewcommand{\parindent}{0pt} % Disable indentation in abstract
    {\vspace{10.5pt}}
    {\fontsize{9}{11}\selectfont\noindent\textbf{\keywordsname:}}
    \small
    {\fontsize{9}{11}\selectfont % Paragraph size 9pt    
    \ignorespaces
    }\noindent\ignorespaces
}




\makeatletter
\renewcommand{\section}{%
  \@startsection
    {section} % Section level
    {1} % Section number
    {\z@} % Indentation of the section title
    {18pt plus 1.2pt minus 1.2pt} % Space before section title (converted from 2.0ex)
    {12pt plus 1.2pt} % Space after section title (converted from 1.0ex)
    {\normalsize\bfseries\MakeUppercase} % Section title font
}

\renewcommand{\subsection}{%
  \@startsection
    {subsection} % Subsection level
    {2} % Level number
    {\z@} % Left indent
    {12pt plus 1.2pt minus 1.2pt} % Space before section title (converted from 2.0ex)
    {12pt plus 1.2pt} % Space after section title (converted from 1.0ex)
    {\normalsize\bfseries} % Style of the title
}

\renewcommand{\subsubsection}{%
  \@startsection
    {subsubsection} % Subsubsection level
    {3} % Level number
    {\z@} % Left indent
    {12pt plus 1.2pt minus 1.2pt} % Space before section title (converted from 2.0ex)
    {6pt plus 1.2pt} % Space after section title (converted from 1.0ex)
    {\normalsize\itshape\bfseries} % Style of the title
}

\renewcommand{\paragraph}{%
  \@startsection
    {paragraph} % Paragraph level
    {4} % Level number
    {\z@} % Left indent
    {1.2pt plus 1.2pt minus 1.2pt} % Space before section title (converted from 2.0ex)
    {1.2pt plus 1.2pt} % Space after section title (converted from 1.0ex)
    {\normalsize\bfseries} % Style of the title
}

\renewcommand{\subparagraph}{%
  \@startsection
    {subparagraph} % Subparagraph level
    {5} % Level number
    {\z@} % Left indent
    {1.2pt plus 1.2pt minus 1.2pt} % Space before section title (converted from 2.0ex)
    {1.2pt plus 1.2pt} % Space after section title (converted from 1.0ex)
    {\normalsize\normalsize\bfseries} % Style of the title
}
\makeatother


\newcommand{\subheadline}{\noalign{\hrule height 0.2pt}}

\newcommand{\thinline}[1]{%
  \noalign{\global\arrayrulewidth=0.2pt} % Adjust thickness here
  \cline{#1}%
  \noalign{\global\arrayrulewidth=0.4pt} % Reset to default thickness after \cline
}

\newcommand{\thickhline}{%
    \noalign{\global\arrayrulewidth=1.0pt}% Change the thickness here (1.5pt in this case)
    \hline
    \noalign{\global\arrayrulewidth=0.4pt}% Reset thickness to default (0.4pt)
}
%\renewcommand{\arraystretch}{1.2}

\renewcommand{\footnotesize}{\fontsize{9}{11}\selectfont}

\newcounter{tablefootnotecounter} % Counter for the table footnotes
\newcommand{\tablefootnote}[2]{%
  \stepcounter{tablefootnotecounter}%

  \textsuperscript{#1}% Place the symbol in the table
  \expandafter\xdef\csname tablefootnote@\thetablefootnotecounter\endcsname{#1: #2}% Store the footnote text globally
}


% % Command to print all stored table footnotes after the table
\newcommand{\printtablefootnotes}{%
{
\raggedright
%\vspace{4pt}
  \setcounter{tablefootnotecounter}{0}% Reset counter for the footnotes
  \begingroup
    \renewcommand\thetablefootnotecounter{\arabic{tablefootnotecounter}}% Use Arabic numbers for footnote labels
    \loop
      \stepcounter{tablefootnotecounter}%
      \ifcsname tablefootnote@\thetablefootnotecounter\endcsname
      \tablefooterfont
        \par\noindent\csname tablefootnote@\thetablefootnotecounter\endcsname\hfill\\
      \repeat
  \endgroup
  }

}




\makeatletter
\newcommand\declaration[1]{%
  \phantomsection % Create a linkable anchor for hyperref
  \addcontentsline{toc}{subsection}{#1}% Add to the PDF bookmarks and TOC
  \@startsection{subsection}
  {2}
  {\z@} % Left indent
  {12pt plus 1.2pt minus 1.2pt} % Space before section title (converted from 2.0ex)
  {0pt} % Space after section title (converted from 1.0ex)
  {\bfseries\normalsize}% Bold and normal size for the title
  *{}
  {\noindent\bfseries\ignorespaces #1:}
  \ignorespaces} % Ignore space after colon
\makeatother

\renewcommand\appendix{\par
  \setcounter{section}{0}%
  \setcounter{subsection}{0}%
  \gdef\thesection{\Alph{section}}% Section numbering: A, B, C...
  \renewcommand{\thetable}{\thesection{A\arabic{table}}}% Table numbering as A1, A2, etc.
  \renewcommand{\thefigure}{\thesection{A\arabic{figure}}}% If you want to include figure numbering as well
  \setcounter{table}{0}% Reset table counter for appendix
  \setcounter{figure}{0}% Reset figure counter for appendix
}
\endinput